if (FALSE) {
# Case 1: Let the function generate the output name in the same folder
mask_to_mosaic(
mosaic_path = "data/IBERIAN_MinMin_all_year_2012_mosaic_res90m.tif",
mask_raster_path = "data/burneable_mask_corine_ETRS89.tif"
)
# Case 2: Save the output to a specific folder, name generated automatically
mask_to_mosaic(
mosaic_path = "data/IBERIAN_MinMin_all_year_2012_mosaic_res90m.tif",
mask_raster_path = "data/burneable_mask_corine_ETRS89.tif",
output_path = "outputs/"
)
# Case 3: Define the full output file name explicitly
mask_to_mosaic(
mosaic_path = "data/IBERIAN_MinMin_all_year_2012_mosaic_res90m.tif",
mask_raster_path = "data/burneable_mask_corine_ETRS89.tif",
output_path = "outputs/custom_masked_output_2012.tif"
)
}
Run the code above in your browser using DataLab